Interface: ActiveElement | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: ActiveElement

## # Hierarchy

- `ActiveDataPoint`

  ↳ `ActiveElement`

## # Properties

### # datasetIndex

• datasetIndex: `number`

#### # Inherited from

ActiveDataPoint.datasetIndex

#### # Defined in

index.esm.d.ts:471
(opens new window)

### # element

• element: `Element`<`AnyObject`, `AnyObject`>

#### # Defined in

index.esm.d.ts:476
(opens new window)

### # index

• index: `number`

#### # Inherited from

ActiveDataPoint.index

#### # Defined in

index.esm.d.ts:472
(opens new window)